@@ -40,11 +40,9 @@ class DataLineage():
     """
     metadata: dict()
 
+    def update(self, metadata:dict):
+        self.metadata = metadata
     def serialize(self):
         """Makes the metadata json friendly
         """
-        return sterilize(self.metadata)
-
-
-
-   
+        return sterilize(self.metadata)
\ No newline at end of file
